@@ -1,10 +1,11 @@
 #!/usr/bin/perl
 #
-# Copyright 2000-2004 The Apache Software Foundation
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+#  contributor license agreements.  See the NOTICE file distributed with
+#  this work for additional information regarding copyright ownership.
+#  The ASF licenses this file to You under the Apache License, Version 2.0
+#  (the "License"); you may not use this file except in compliance with
+#  the License.  You may obtain a copy of the License at
 #
 #      http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -84,7 +85,7 @@ if(($^O eq "MSWin32") || ($^O eq "dos") || ($^O eq "cygwin") ||
         }
 
 #build up standard classpath
-my $localpath = "/usr/local/lib/java/ant/ant-launcher.jar";
+my $localpath = "/usr/local/ant/lib/ant-launcher.jar";
 #set JVM options and Ant arguments, if any
 my @ANT_OPTS=split(" ", $ENV{ANT_OPTS});
 my @ANT_ARGS=split(" ", $ENV{ANT_ARGS});
